@@ -39,6 +39,10 @@ module GLib
       self
     end
 
+    def ==(other)
+      self.to_a == other.to_a
+    end
+
     private
 
     def reset_iterator
