@@ -1,6 +1,10 @@
 module GLib
   # Extra methods for GLib::Strv. The bulk is defined in `gir_ffi-base/glib/strv.rb`
   class Strv
+    def ==(other)
+      self.to_a == other.to_a
+    end
+
     def self.from it
       case it
       when nil
@@ -19,4 +23,3 @@ module GLib
     end
   end
 end
-
