@@ -10,13 +10,9 @@ require 'ffi-gobject/initially_unowned'
 require 'ffi-gobject/closure'
 require 'ffi-gobject/object'
 require 'ffi-gobject/ruby_closure'
-require 'gir_ffi/builder/type/user_defined'
+require 'gir_ffi/builders/user_defined_builder'
 
 module GObject
-  def self.type_init
-    Lib::g_type_init
-  end
-
   def self.object_ref obj
     Lib::g_object_ref obj.to_ptr
   end
@@ -76,9 +72,9 @@ module GObject
     signal, _ = detailed_signal.split('::')
     sig_info = object.class.find_signal signal
     callback = sig_info.signal_callback(&block)
-    GirFFI::CallbackHelper.store_callback callback
+    GirFFI::CallbackBase.store_callback callback
 
-    data_ptr = GirFFI::ArgHelper.object_to_inptr data
+    data_ptr = GirFFI::InPointer.from_object data
 
     Lib.g_signal_connect_data object, detailed_signal, callback, data_ptr, nil, 0
   end
@@ -105,13 +101,13 @@ module GObject
     attach_function :g_object_unref, [:pointer], :void
     attach_function :g_object_is_floating, [:pointer], :bool
 
-    attach_function :g_strv_get_type, [], :size_t
+    attach_function :g_array_get_type, [], :size_t
     attach_function :g_hash_table_get_type, [], :size_t
+    attach_function :g_strv_get_type, [], :size_t
 
     attach_function :g_signal_connect_data,
-      [:pointer, :string, Callback, :pointer, ClosureNotify,
-        ConnectFlags],
-        :ulong
+      [:pointer, :string, Callback, :pointer, ClosureNotify, ConnectFlags],
+      :ulong
     attach_function :g_closure_set_marshal,
       [:pointer, ClosureMarshal], :void
 
@@ -120,17 +116,19 @@ module GObject
       :pointer
   end
 
-  TYPE_STRV = Lib.g_strv_get_type
+  TYPE_ARRAY = Lib.g_array_get_type
   TYPE_HASH_TABLE = Lib.g_hash_table_get_type
+  TYPE_STRV = Lib.g_strv_get_type
 
   TYPE_TAG_TO_GTYPE = {
-    :void => TYPE_NONE,
+    :array => TYPE_ARRAY,
     :gboolean => TYPE_BOOLEAN,
-    :gint32 => TYPE_INT,
-    :gfloat => TYPE_FLOAT,
     :gdouble => TYPE_DOUBLE,
-    :utf8 => TYPE_STRING,
+    :gfloat => TYPE_FLOAT,
     :ghash => TYPE_HASH_TABLE,
-    :glist => TYPE_POINTER
+    :gint32 => TYPE_INT,
+    :glist => TYPE_POINTER,
+    :utf8 => TYPE_STRING,
+    :void => TYPE_NONE
   }
 end
