@@ -37,13 +37,12 @@ module GObject
       return closure
     end
 
-    # TODO: Use invocation_hint and marshal_data
     def self.marshaller(closure, return_value, n_param_values,
                         param_values, _invocation_hint, _marshal_data)
       rclosure = wrap(closure.to_ptr)
 
       args = n_param_values.times.map {|idx|
-        Value.wrap(param_values.to_ptr + idx * Value::Struct.size).ruby_value
+        Value.wrap(param_values.to_ptr + idx * Value::Struct.size).get_value
       }
 
       result = rclosure.invoke_block(*args)
