@@ -14,17 +14,30 @@ module GObject
 
     TYPE_TO_SET_METHOD_MAP = {
       TYPE_BOOLEAN => :set_boolean,
-      TYPE_INT => :set_int,
-      TYPE_STRING => :set_string,
-      TYPE_FLOAT => :set_float,
-      TYPE_DOUBLE => :set_double,
-      TYPE_PARAM => :set_param,
-      TYPE_OBJECT => :set_instance_enhanced,
       TYPE_BOXED => :set_boxed,
+      TYPE_CHAR => :set_char,
+      TYPE_DOUBLE => :set_double,
+      TYPE_ENUM => :set_enum,
+      TYPE_FLOAT => :set_float,
+      TYPE_GTYPE => :set_gtype,
+      TYPE_INT64 => :set_int64,
+      TYPE_INT => :set_int,
+      TYPE_LONG => :set_long,
+      TYPE_OBJECT => :set_instance_enhanced,
+      TYPE_PARAM => :set_param,
       TYPE_POINTER => :set_pointer,
-      TYPE_ENUM => :set_enum
+      TYPE_STRING => :set_string,
+      TYPE_UCHAR => :set_uchar,
+      TYPE_UINT => :set_uint,
+      TYPE_UINT64 => :set_uint64,
+      TYPE_ULONG => :set_ulong,
+      TYPE_VARIANT => :set_variant,
     }
 
+    def value= val
+      set_value val
+    end
+
     def set_value val
       send set_method, val
       self
@@ -61,20 +74,42 @@ module GObject
 
     TYPE_TO_GET_METHOD_MAP = {
       TYPE_BOOLEAN => :get_boolean,
-      TYPE_INT => :get_int,
-      TYPE_STRING => :get_string,
-      TYPE_FLOAT => :get_float,
+      TYPE_BOXED => :get_boxed,
+      TYPE_CHAR => :get_char,
       TYPE_DOUBLE => :get_double,
+      TYPE_FLOAT => :get_float,
+      TYPE_GTYPE => :get_gtype,
+      TYPE_INT64 => :get_int64,
+      TYPE_INT => :get_int,
+      TYPE_LONG => :get_long,
       TYPE_OBJECT => :get_object,
-      TYPE_BOXED => :get_boxed_enhanced,
-      TYPE_POINTER => :get_pointer
+      TYPE_POINTER => :get_pointer,
+      TYPE_STRING => :get_string,
+      TYPE_UCHAR => :get_uchar,
+      TYPE_UINT => :get_uint,
+      TYPE_UINT64 => :get_uint64,
+      TYPE_ULONG => :get_ulong,
+      TYPE_VARIANT => :get_variant,
     }
 
-    # TODO: Rename to get_value
-    def ruby_value
+    def get_value
+      value = get_value_plain
+      if current_fundamental_type == TYPE_BOXED
+        wrap_boxed value
+      else
+        value
+      end
+    end
+
+    def get_value_plain
       send get_method
     end
 
+    # @deprecated Compatibility function. Remove in 0.7.0.
+    def ruby_value
+      get_value
+    end
+
     class << self
       # TODO: Give more generic name
       def wrap_ruby_value val
@@ -119,27 +154,26 @@ module GObject
       end
     end
 
-    def get_boxed_enhanced
-      boxed = get_boxed
-      gtype = current_gtype
-
-      case gtype
+    def wrap_boxed boxed
+      case current_gtype
       when TYPE_STRV
         GLib::Strv.wrap boxed
       when TYPE_HASH_TABLE
         GLib::HashTable.wrap [:gpointer, :gpointer], boxed
       else
-        GirFFI::ArgHelper.wrap_object_pointer_by_gtype boxed, gtype
+        boxed.wrap_by_gtype current_gtype
       end
     end
 
     def get_method
-      TYPE_TO_GET_METHOD_MAP[current_fundamental_type] or
+      TYPE_TO_GET_METHOD_MAP[current_gtype] or
+        TYPE_TO_GET_METHOD_MAP[current_fundamental_type] or
         raise "Can't find method to get #{current_gtype_name}"
     end
 
     def set_method
-      TYPE_TO_SET_METHOD_MAP[current_fundamental_type] or
+      TYPE_TO_SET_METHOD_MAP[current_gtype] or
+        TYPE_TO_SET_METHOD_MAP[current_fundamental_type] or
         raise "Can't find method to set #{current_gtype_name}"
     end
   end
