@@ -25,13 +25,20 @@ module GObjectIntrospection
     # of the methods returning their number and the individual elements.
     #
     # For example, given the methods +n_foos+ and +foo+(+i+), this method
-    # will create an additional method +foos+ returning all args.
+    # will create an additional method +foos+ returning all foos.
     #
     # Provide the second parameter if the plural is not trivially
     # constructed by adding +s+ to the singular.
+    #
+    # Examples:
+    #
+    #   build_array_method :fields
+    #   build_array_mehtod :properties, :property
+    #   build_array_method :get_methods
+    #
     def self.build_array_method method, single = nil
       method = method.to_s
-      single ||= method[0..-2]
+      single ||= method.to_s[0..-2]
       count = method.sub(/^(get_)?/, "\\1n_")
       self.class_eval <<-CODE
         def #{method}
@@ -42,6 +49,38 @@ module GObjectIntrospection
       CODE
     end
 
+    # This is a helper method to construct a method for finding an element, out
+    # of the methods returning their number and the individual elements.
+    #
+    # For example, given the methods +n_foos+ and +foo+(+i+), this method will
+    # create an additional method +find_foo+ returning the foo with the
+    # matching name.
+    #
+    # Optionally provide counter and fetcher methods if they cannot be
+    # trivially derived from the finder method.
+    #
+    # Examples:
+    #
+    #   build_finder_method :find_field
+    #   build_finder_method :find_property, :n_properties
+    #   build_finder_method :find_method, :get_n_methods, :get_method
+    #
+    def self.build_finder_method method, counter = nil, fetcher = nil
+      method = method.to_s
+      single = method.sub(/^find_/, "")
+      counter ||= "n_#{single}s"
+      fetcher ||= "#{single}"
+      self.class_eval <<-CODE
+        def #{method}(name)
+          (0..(#{counter} - 1)).each do |i|
+            it = #{fetcher}(i)
+            return it if it.name == name
+          end
+          nil
+        end
+      CODE
+    end
+
     def name
       Lib.g_base_info_get_name @gobj
     end
@@ -60,6 +99,7 @@ module GObjectIntrospection
 
     def container
       ptr = Lib.g_base_info_get_container @gobj
+      Lib.g_base_info_ref ptr
       IRepository.wrap_ibaseinfo_pointer ptr
     end
 
