@@ -1,8 +1,15 @@
 module GObjectIntrospection
-  # Wraps a GIConstantInfo struct; represents an constant.
+  # Wraps a GIConstantInfo struct; represents a constant.
   class IConstantInfo < IBaseInfo
     TYPE_TAG_TO_UNION_MEMBER = {
+      :gint8 => :v_int8,
+      :gint16 => :v_int16,
       :gint32 => :v_int32,
+      :gint64 => :v_int64,
+      :guint8 => :v_uint8,
+      :guint16 => :v_uint16,
+      :guint32 => :v_uint32,
+      :guint64 => :v_uint64,
       :gdouble => :v_double,
       :utf8 => :v_string
     }
