@@ -28,9 +28,5 @@ module GObjectIntrospection
     def throws?
       flags & 32 != 0
     end
-
-    def safe_name
-      name == '' ? '_' : name
-    end
   end
 end
