@@ -1,6 +1,8 @@
 require 'singleton'
+require 'ffi'
+require 'gir_ffi-base'
+
 require 'ffi-gobject_introspection/lib'
-require 'ffi-gobject_introspection/gobject_lib'
 require 'ffi-gobject_introspection/g_error'
 require 'ffi-gobject_introspection/i_base_info'
 require 'ffi-gobject_introspection/i_callable_info'
@@ -21,7 +23,7 @@ require 'ffi-gobject_introspection/i_enum_info'
 require 'ffi-gobject_introspection/i_flags_info'
 
 module GObjectIntrospection
-  GObjectLib::g_type_init
+  GObject.type_init
 
   # The Gobject Introspection Repository. This class is the point of
   # access to the introspection typelibs.
@@ -52,8 +54,6 @@ module GObjectIntrospection
       :unresolved => IBaseInfo
     }
 
-    POINTER_SIZE = FFI.type_size(:pointer)
-
     def initialize
       @gobj = Lib::g_irepository_get_default
     end
@@ -78,7 +78,7 @@ module GObjectIntrospection
       Lib.g_irepository_require @gobj, namespace, version, flags, errpp
 
       errp = errpp.read_pointer
-      raise GError.new(errp)[:message] unless errp.null?
+      raise GError.new(errp).message unless errp.null?
     end
 
     def n_infos namespace
@@ -93,7 +93,7 @@ module GObjectIntrospection
     # Utility method
     def infos namespace
       (0..(n_infos(namespace) - 1)).map do |idx|
-	info namespace, idx
+        info namespace, idx
       end
     end
 
@@ -103,13 +103,15 @@ module GObjectIntrospection
     end
 
     def find_by_gtype gtype
+      raise ArgumentError, "Type #{gtype} is not a valid type" if gtype == 0
       ptr = Lib.g_irepository_find_by_gtype @gobj, gtype
       return wrap ptr
     end
 
     def dependencies namespace
-      strv = Lib.g_irepository_get_dependencies @gobj, namespace
-      strv_to_utf8_array strv
+      strv_p = Lib.g_irepository_get_dependencies(@gobj, namespace)
+      strv = GLib::Strv.new strv_p
+      strv.to_a
     end
 
     def shared_library namespace
@@ -130,15 +132,5 @@ module GObjectIntrospection
     def wrap ptr
       IRepository.wrap_ibaseinfo_pointer ptr
     end
-
-    def strv_to_utf8_array strv
-      return [] if strv.null?
-      arr, offset = [], 0
-      until (ptr = strv.get_pointer offset).null? do
-        arr << ptr.read_string
-        offset += POINTER_SIZE
-      end
-      return arr
-    end
   end
 end
