@@ -11,6 +11,7 @@ module GObjectIntrospection
 
     ##
     build_array_method :fields
+    build_finder_method :find_field
 
     def get_n_methods
       Lib.g_struct_info_get_n_methods @gobj
@@ -21,11 +22,8 @@ module GObjectIntrospection
 
     ##
     build_array_method :get_methods
-
-    def find_method(name)
-      @methods_hash ||= make_method_hash
-      @methods_hash[name]
-    end
+    # There is a function g_object_info_find_method but it causes a core dump.
+    build_finder_method :find_method, :get_n_methods, :get_method
 
     def size
       Lib.g_struct_info_get_size @gobj
@@ -38,13 +36,5 @@ module GObjectIntrospection
     def gtype_struct?
       Lib.g_struct_info_is_gtype_struct @gobj
     end
-
-    private
-
-    def make_method_hash
-      Hash.new.tap do |hash|
-        get_methods.each {|mth| hash[mth.name] = mth }
-      end
-    end
   end
 end
