@@ -49,6 +49,7 @@ module GObjectIntrospection
       :unresolved
     ]
 
+    attach_function :g_base_info_ref, [:pointer], :void
     attach_function :g_base_info_unref, [:pointer], :void
     attach_function :g_base_info_get_type, [:pointer], :IInfoType
     attach_function :g_base_info_get_name, [:pointer], :string
@@ -74,6 +75,7 @@ module GObjectIntrospection
     attach_function :g_callable_info_may_return_null, [:pointer], :bool
     attach_function :g_callable_info_get_n_args, [:pointer], :int
     attach_function :g_callable_info_get_arg, [:pointer, :int], :pointer
+    attach_function :g_callable_info_skip_return, [:pointer], :bool
 
     # IArgInfo
     enum :IDirection, [
@@ -93,6 +95,7 @@ module GObjectIntrospection
     attach_function :g_arg_info_is_return_value, [:pointer], :bool
     attach_function :g_arg_info_is_optional, [:pointer], :bool
     attach_function :g_arg_info_is_caller_allocates, [:pointer], :bool
+    attach_function :g_arg_info_is_skip, [:pointer], :bool
     attach_function :g_arg_info_may_be_null, [:pointer], :bool
     attach_function :g_arg_info_get_ownership_transfer, [:pointer], :ITransfer
     attach_function :g_arg_info_get_scope, [:pointer], :IScopeType
@@ -178,6 +181,8 @@ module GObjectIntrospection
     attach_function :g_enum_info_get_storage_type, [:pointer], :ITypeTag
     attach_function :g_enum_info_get_n_values, [:pointer], :int
     attach_function :g_enum_info_get_value, [:pointer, :int], :pointer
+    attach_function :g_enum_info_get_n_methods, [:pointer], :int
+    attach_function :g_enum_info_get_method, [:pointer, :int], :pointer
 
     # IObjectInfo
     attach_function :g_object_info_get_type_name, [:pointer], :string
