@@ -1,17 +1,17 @@
 require 'ffi'
 
-require 'gir_ffi/class_base'
-require 'gir_ffi/type_map'
+require 'gir_ffi-base'
 
 require 'ffi-gobject_introspection'
-require 'gir_ffi/info_ext'
 
+require 'gir_ffi/ffi_ext'
+require 'gir_ffi/class_base'
+require 'gir_ffi/type_map'
+require 'gir_ffi/info_ext'
 require 'gir_ffi/in_pointer'
 require 'gir_ffi/in_out_pointer'
 require 'gir_ffi/zero_terminated'
 require 'gir_ffi/arg_helper'
-require 'gir_ffi/callback'
-require 'gir_ffi/callback_helper'
 require 'gir_ffi/builder'
 
 module GirFFI
@@ -22,7 +22,7 @@ module GirFFI
 
   def self.define_type klass, &block
     info = UserDefinedTypeInfo.new(klass, &block)
-    Builder::Type::UserDefined.new(info).build_class
+    Builders::UserDefinedBuilder.new(info).build_class
 
     klass.get_gtype
   end
