@@ -1,14 +1,19 @@
 require 'forwardable'
-require 'gir_ffi/ffi_ext/pointer'
+require 'gir_ffi/builders/null_builder'
+require 'gir_ffi/type_base'
 
 module GirFFI
   # Base class for all generated classes. Contains code for dealing with
   # the generated Struct classes.
   class ClassBase
+    extend TypeBase
+
     # TODO: Make separate base for :struct, :union, :object.
     extend Forwardable
     def_delegators :@struct, :to_ptr
 
+    GIR_FFI_BUILDER = NullBuilder.new
+
     def setup_and_call method, *arguments, &block
       result = self.class.ancestors.any? do |klass|
         klass.respond_to?(:setup_instance_method) &&
@@ -22,6 +27,18 @@ module GirFFI
       self.send method, *arguments, &block
     end
 
+    if RUBY_PLATFORM == 'java'
+      # FIXME: JRuby should fix FFI::MemoryPointer#== to return true for
+      # equivalent FFI::Pointer.
+      def ==(other)
+        other.class == self.class && self.to_ptr.address == other.to_ptr.address
+      end
+    else
+      def ==(other)
+        other.class == self.class && self.to_ptr == other.to_ptr
+      end
+    end
+
     def self.setup_and_call method, *arguments, &block
       result = self.ancestors.any? do |klass|
         klass.respond_to?(:setup_method) &&
@@ -36,12 +53,8 @@ module GirFFI
     end
 
     class << self
-      def gir_info
-        self.const_get :GIR_INFO
-      end
-
-      def gir_ffi_builder
-        self.const_get :GIR_FFI_BUILDER
+      def to_ffitype
+        self::Struct
       end
 
       def setup_method name
