@@ -9,6 +9,11 @@ module GirFFI
       def return_ffi_type
         return_type.to_ffitype
       end
+
+      # TODO: Move to extension just for ICallbackInfo
+      def to_ffitype
+        Builder.build_class(self)
+      end
     end
   end
 end
