@@ -1,11 +1,10 @@
-require 'gir_ffi/info_ext/i_type_info'
-
 module GirFFI
   module InfoExt
+    # Extensions for GObjectIntrospection::IFieldInfo needed by GirFFI
     module IFieldInfo
       def layout_specification
         [ name.to_sym,
-          field_type.layout_specification_type,
+          field_type.to_ffitype,
           offset ]
       end
     end
