@@ -20,23 +20,6 @@ module GirFFI
         GObject::Value.for_g_type g_type
       end
 
-      def layout_specification_type
-        ffitype = self.to_ffitype
-        case ffitype
-        when Class
-          ffitype.const_get :Struct
-        when :array
-          subtype = param_type(0).layout_specification_type
-          # XXX Don't use pointer directly to appease JRuby.
-          if subtype == :pointer
-            subtype = :"uint#{FFI.type_size(:pointer)*8}"
-          end
-          [subtype, array_fixed_size]
-        else
-          ffitype
-        end
-      end
-
       def element_type
         case tag
         when :glist, :gslist, :array
@@ -48,68 +31,62 @@ module GirFFI
         end
       end
 
-      def interface_type_name
-        interface.full_type_name
-      end
-
       def flattened_tag
-        type_tag = self.tag
-        case type_tag
+        case tag
         when :interface
           interface_type
         when :array
           flattened_array_type
         else
-          type_tag
+          tag
         end
       end
 
       def interface_type
-        interface.info_type
-      end
-
-      def flattened_array_type
-        if zero_terminated?
-          zero_terminated_array_type
-        else
-          array_type
-        end
-      end
-
-      def subtype_tag_or_class_name index = 0
-        param_type(index).tag_or_class_name
+        tag == :interface && interface.info_type
       end
 
       def subtype_tag_or_class index = 0
         param_type(index).tag_or_class
       end
 
-      # TODO: Merge with tag_or_class
-      def tag_or_class_name
-        type_tag = self.tag
-        base = if type_tag == :interface
-                 interface_type_name
+      def tag_or_class
+        base = case flattened_tag
+               when :struct, :union, :object, :interface, :enum, :flags
+                 Builder.build_class interface
                else
-                 type_tag.inspect
+                 flattened_tag
                end
-        if pointer? && type_tag != :utf8 && type_tag != :filename
-          "[:pointer, #{base}]"
+        if pointer? && tag != :utf8 && tag != :filename || interface_type == :object
+          [:pointer, base]
         else
           base
         end
       end
 
-      def tag_or_class
-        type_tag = self.tag
-        base = if type_tag == :interface
-                 Builder.build_class interface
-               else
-                 type_tag
-               end
-        if pointer? && type_tag != :utf8 && type_tag != :filename
-          [:pointer, base]
+      TAG_TO_WRAPPER_CLASS_MAP = {
+        :array => 'GLib::Array',
+        :byte_array => 'GLib::ByteArray',
+        :c => 'GLib::SizedArray',
+        :callback => 'GirFFI::Callback',
+        :error => 'GLib::Error',
+        :ghash => 'GLib::HashTable',
+        :glist => 'GLib::List',
+        :gslist => 'GLib::SList',
+        :ptr_array => 'GLib::PtrArray',
+        :strv => 'GLib::Strv',
+        :utf8 => 'GirFFI::InPointer',
+        :void => 'GirFFI::InPointer',
+        :zero_terminated => 'GirFFI::ZeroTerminated'
+      }
+
+      # TODO: Use class rather than class name
+      def argument_class_name
+        case flattened_tag
+        when :struct, :union, :object, :interface, :enum, :flags, :callback
+          interface.full_type_name
         else
-          base
+          TAG_TO_WRAPPER_CLASS_MAP[flattened_tag]
         end
       end
 
@@ -117,8 +94,16 @@ module GirFFI
         return :pointer if pointer?
 
         type_tag = tag
-        if type_tag == :interface
-          Builder.build_class interface
+        case type_tag
+        when :interface
+          interface.to_ffitype
+        when :array
+          subtype = param_type(0).to_ffitype
+          # NOTE: Don't use pointer directly to appease JRuby.
+          if subtype == :pointer
+            subtype = :"uint#{FFI.type_size(:pointer)*8}"
+          end
+          [subtype, array_fixed_size]
         else
           TypeMap.map_basic_type type_tag
         end
@@ -127,7 +112,6 @@ module GirFFI
       def to_callback_ffitype
         type_tag = tag
 
-        return :string if type_tag == :utf8
         return :pointer if pointer?
 
         if type_tag == :interface
@@ -141,14 +125,35 @@ module GirFFI
           return TypeMap.map_basic_type type_tag
         end
       end
+
+      def extra_conversion_arguments
+        case flattened_tag
+        when :utf8, :void
+          [flattened_tag]
+        when :c
+          [subtype_tag_or_class, array_fixed_size]
+        when :array, :ghash, :glist, :gslist, :ptr_array, :zero_terminated
+          [element_type]
+        else
+          []
+        end
+      end
+
       private
 
+      def flattened_array_type
+        if zero_terminated?
+          zero_terminated_array_type
+        else
+          array_type
+        end
+      end
+
       def zero_terminated_array_type
         case element_type
         when :utf8, :filename
           :strv
         else
-          # TODO: Check that array_type == :c
           :zero_terminated
         end
       end
