@@ -4,10 +4,20 @@ module GirFFI
     gtype_type = "uint#{sz}".to_sym
 
     TAG_TYPE_MAP = {
-      #FIXME: Pick one: GType or gtype.
-      :GType => :size_t,
-      :gtype => gtype_type,
-      :gboolean => :bool,
+      :enum => :int32,
+      :flags => :int32,
+      :ghash => :pointer,
+      :glist => :pointer,
+      :gslist => :pointer,
+      :strv => :pointer,
+      :object => :pointer,
+      :struct => :pointer,
+      :error => :pointer,
+      :ptr_array => :pointer,
+      :array => :pointer,
+      :utf8 => :pointer,
+      :GType => gtype_type,
+      :gboolean => GLib::Boolean,
       :gunichar => :uint32,
       :gint8 => :int8,
       :guint8 => :uint8,
@@ -24,16 +34,16 @@ module GirFFI
     }
 
     def self.map_basic_type type
-      TAG_TYPE_MAP[type] || type
+      sym = type.to_sym
+      TAG_TYPE_MAP[sym] || sym
     end
 
-    # FIXME: Make name more descriptive.
-    def self.map_basic_type_or_string type
+    def self.type_specification_to_ffitype type
       case type
-      when :gboolean
-        :int32
-      when :utf8
-        :pointer
+      when Module
+        type.to_ffitype
+      when Array
+        type[0]
       else
         map_basic_type(type)
       end
