@@ -1,4 +1,4 @@
-require File.expand_path('../gir_ffi_test_helper.rb', File.dirname(__FILE__))
+require 'gir_ffi_test_helper'
 
 describe GLib::HashTable do
   it "knows its key and value types" do
@@ -17,7 +17,7 @@ describe GLib::HashTable do
     it "return its argument if given a GHashTable" do
       hsh = GLib::HashTable.from [:utf8, :gint32], {"foo" => 23, "bar" => 32}
       hsh2 = GLib::HashTable.from [:utf8, :gint32], hsh
-      assert_equal hsh, hsh2
+      assert hsh2.equal? hsh
     end
 
     it "wraps its argument if given a pointer" do
@@ -26,8 +26,37 @@ describe GLib::HashTable do
       assert_instance_of FFI::Pointer, pointer
       hsh2 = GLib::HashTable.from [:utf8, :gint32], pointer
       assert_instance_of GLib::HashTable, hsh2
-      refute_equal hsh, hsh2
-      assert_equal hsh.to_hash, hsh2.to_hash
+      refute hsh2.equal? hsh
+      hsh2.to_hash.must_equal hsh.to_hash
+    end
+  end
+
+  it "allows key-value pairs to be inserted" do
+    h = GLib::HashTable.new :utf8, :utf8
+    h.insert "foo", "bar"
+    h.to_hash.must_equal "foo" => "bar"
+  end
+
+  it "includes Enumerable" do
+    GLib::HashTable.must_include Enumerable 
+  end
+
+  describe "a HashTable provided by the system" do
+    before do
+      GirFFI.setup :Regress
+      @hash = Regress.test_ghash_container_return
+    end
+
+    it "has a working #each method" do
+      a = {}
+      @hash.each {|k, v| a[k] = v}
+      a.must_be :==, {"foo" => "bar", "baz" => "bat",
+        "qux" => "quux"}
+    end
+
+    it "has a working #to_hash method" do
+      @hash.to_hash.must_be :==, {"foo" => "bar", "baz" => "bat",
+        "qux" => "quux"}
     end
   end
 end
