@@ -1,4 +1,4 @@
-require File.expand_path('../gir_ffi_test_helper.rb', File.dirname(__FILE__))
+require 'gir_ffi_test_helper'
 
 describe GLib::List do
   it "knows its element type" do
@@ -40,7 +40,7 @@ describe GLib::List do
     it "return its argument if given a GList" do
       lst = GLib::List.from :gint32, [3, 2, 1]
       lst2 = GLib::List.from :gint32, lst
-      assert_equal lst, lst2
+      assert lst2.equal? lst
     end
 
     it "wraps its argument if given a pointer" do
@@ -49,8 +49,36 @@ describe GLib::List do
       assert_instance_of FFI::Pointer, pointer
       lst2 = GLib::List.from :gint32, pointer
       assert_instance_of GLib::List, lst2
-      refute_equal lst, lst2
-      assert_equal lst.to_a, lst2.to_a
+      refute lst2.equal? lst
+      lst2.to_a.must_equal lst.to_a
+    end
+  end
+
+  describe "#==" do
+    it "returns true when comparing to an array with the same elements" do
+      list = GLib::List.from :gint32, [1, 2, 3]
+
+      list.must_be :==, [1, 2, 3]
+    end
+
+    it "returns false when comparing to an array with different elements" do
+      list = GLib::List.from :gint32, [1, 2, 3]
+
+      list.wont_be :==, [1, 2]
+    end
+
+    it "returns true when comparing to a list with the same elements" do
+      list = GLib::List.from :gint32, [1, 2, 3]
+      other = GLib::List.from :gint32, [1, 2, 3]
+
+      list.must_be :==, other
+    end
+
+    it "returns false when comparing to a list with different elements" do
+      list = GLib::List.from :gint32, [1, 2, 3]
+      other = GLib::List.from :gint32, [1, 2]
+
+      list.wont_be :==, other
     end
   end
 end
