@@ -2,14 +2,14 @@ require 'introspection_test_helper'
 
 describe GObjectIntrospection::IObjectInfo do
   describe "#find_vfunc" do
-    setup do
+    before do
       gir = GObjectIntrospection::IRepository.default
       gir.require 'GObject', nil
       @info = gir.find_by_name 'GObject', 'Object'
     end
 
-    should "find a vfunc by name" do
-      assert_not_nil @info.find_vfunc("finalize")
+    it "finds a vfunc by name" do
+      @info.find_vfunc("finalize").wont_be_nil
     end
   end
 end
