@@ -2,29 +2,6 @@ require 'introspection_test_helper'
 
 require 'gir_ffi'
 
-GObjectIntrospection::IRepository.prepend_search_path File.join(File.dirname(__FILE__), 'lib')
-module GObjectIntrospection
-  class IRepository
-    def shared_library_with_regress namespace
-      case namespace
-      when "Regress"
-        return File.join(File.dirname(__FILE__), 'lib', 'libregress.so')
-      when "GIMarshallingTests"
-        return File.join(File.dirname(__FILE__), 'lib', 'libgimarshallingtests.so')
-      else
-        return shared_library_without_regress namespace
-      end
-    end
-
-    alias shared_library_without_regress shared_library
-    alias shared_library shared_library_with_regress
-  end
-end
-
-# Need a dummy module for some tests.
-module DummyLib
-end
-
 # Global sequence provider. Needed to make unique class names.
 class Sequence
   @@seq = 0
@@ -38,10 +15,22 @@ class Minitest::Test
     code.gsub(/(^\s*|\s*$)/, "")
   end
 
+  def get_field_introspection_data namespace, klass, name
+    get_introspection_data(namespace, klass).find_field name
+  end
+
   def get_method_introspection_data namespace, klass, name
     get_introspection_data(namespace, klass).find_method name
   end
 
+  def get_property_introspection_data namespace, klass, name
+    get_introspection_data(namespace, klass).find_property name
+  end
+
+  def get_signal_introspection_data namespace, klass, name
+    get_introspection_data(namespace, klass).find_signal name
+  end
+
   SAVED_MODULES = {}
 
   def save_module name
